==> hypre_2.13.0.orig.tar.gz: hypre-2.13.0/src/FEI_mv/ml/src/Include/ml_include.h <==
/*BHEADER**********************************************************************
 * Copyright (c) 2008,  Lawrence Livermore National Security, LLC.
 * Produced at the Lawrence Livermore National Laboratory.
 * This file is part of HYPRE.  See file COPYRIGHT for details.
 *
 * HYPRE is free software; you can redistribute it and/or modify it under the
 * terms of the GNU Lesser General Public License (as published by the Free
 * Software Foundation) version 2.1 dated February 1999.
 *
 * $Revision$
 ***********************************************************************EHEADER*/




/* ******************************************************************** */
/* See the file COPYRIGHT for a complete copyright notice, contact      */
/* person and disclaimer.                                               */        
/* ******************************************************************** */

/* ******************************************************************** */
/* Include file                                                         */
/* ******************************************************************** */
/* Author        : Charles Tong (LLNL) and Raymond Tuminaro (SNL)       */
/* Date          : January, 1998                                        */
/* ******************************************************************** */

#ifndef _MLINCLUDE_
#define _MLINCLUDE_

#include "ml_common.h"
#include "ml_defs.h"
#include "ml_struct.h"
#include "ml_agg_genP.h"
#include "ml_aggregate.h"
#include "ml_amg.h"
#include "ml_amg_genP.h"
#include "ml_bicgstabl.h"
#include "ml_cg.h"
#include "ml_comm.h"
#include "ml_gmres.h"
#include "ml_grid.h"
#include "ml_gridagx.h"
#include "ml_gridfunc.h"
#include "ml_krylov.h"
#include "ml_operator.h"
#include "mli_solver.h"
#include "ml_pde.h"
#include "ml_solver.h"
#include "ml_vec.h"
#include "ml_elementagx.h"
#include "ml_intlist.h"
#include "ml_operatoragx.h"
#include "ml_xyt.h"
#include "ml_op_utils.h"
#include "ml_operator_blockmat.h"
#include "ml_agg_reitzinger.h"
#include "ml_aztec_utils.h"
#include "ml_memory.h"
#include "ml_vampir.h"
#include "ml_amesos.h"
#include "ml_ifpack.h"
#include "ml_agg_METIS.h"
#include "ml_agg_ParMETIS.h"

#endif

==> hypre_2.16.0.orig.tar.gz: hypre-2.16.0/src/FEI_mv/ml/src/Include/ml_include.h <==
/*BHEADER**********************************************************************
 * Copyright (c) 2008,  Lawrence Livermore National Security, LLC.
 * Produced at the Lawrence Livermore National Laboratory.
 * This file is part of HYPRE.  See file COPYRIGHT for details.
 *
 * HYPRE is free software; you can redistribute it and/or modify it under the
 * terms of the GNU Lesser General Public License (as published by the Free
 * Software Foundation) version 2.1 dated February 1999.
 *
 * $Revision$
 ***********************************************************************EHEADER*/




/* ******************************************************************** */
/* See the file COPYRIGHT for a complete copyright notice, contact      */
/* person and disclaimer.                                               */        
/* ******************************************************************** */

/* ******************************************************************** */
/* Include file                                                         */
/* ******************************************************************** */
/* Author        : Charles Tong (LLNL) and Raymond Tuminaro (SNL)       */
/* Date          : January, 1998                                        */
/* ******************************************************************** */

#ifndef _MLINCLUDE_
#define _MLINCLUDE_

#include "ml_common.h"
#include "ml_defs.h"
#include "ml_struct.h"
#include "ml_agg_genP.h"
#include "ml_aggregate.h"
#include "ml_amg.h"
#include "ml_amg_genP.h"
#include "ml_bicgstabl.h"
#include "ml_cg.h"
#include "ml_comm.h"
#include "ml_gmres.h"
#include "ml_grid.h"
#include "ml_gridagx.h"
#include "ml_gridfunc.h"
#include "ml_krylov.h"
#include "ml_operator.h"
#include "mli_solver.h"
#include "ml_pde.h"
#include "ml_solver.h"
#include "ml_vec.h"
#include "ml_elementagx.h"
#include "ml_intlist.h"
#include "ml_operatoragx.h"
#include "ml_xyt.h"
#include "ml_op_utils.h"
#include "ml_operator_blockmat.h"
#include "ml_agg_reitzinger.h"
#include "ml_aztec_utils.h"
#include "ml_memory.h"
//#include "ml_vampir.h"
#include "ml_amesos.h"
#include "ml_ifpack.h"
#include "ml_agg_METIS.h"
#include "ml_agg_ParMETIS.h"

#endif
